yt.visualization.plot_window.OffAxisSlicePlot.set_cmap — The yt Project 3.2-dev documentation

# yt.visualization.plot_window.OffAxisSlicePlot.set_cmap

`OffAxisSlicePlot.` `set_cmap`(*args, **kwargs)

  set the colormap for one of the fields

  Parameters: | field : string the field to set the colormap if field == ‘all’, applies to all plots. cmap : string or tuple If a string, will be interpreted as name of the colormap. If a tuple, it is assumed to be of the form (name, type, number) to be used for palettable functionality. (name, type, number, bool) can be used to specify if a reverse colormap is to be used.